@@ -1,15 +1,12 @@
 #define _GNU_SOURCE
-#include <libgen.h>
 #include <ctype.h>
+#include <errno.h>
 #include <getopt.h>
-#include <stdarg.h>
-#include <stdint.h>
+#include <libgen.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <stdbool.h>
+#include <unistd.h>
 
 #include "include/hcxeiutool.h"
 
@@ -151,7 +148,7 @@ fprintf(stdout, "%s %s (C) %s ZeroBeat\n"
 	"-d <file> : output digit wordlist\n"
 	"-x <file> : output xdigit wordlist\n"
 	"-c <file> : output character wordlist (A-Za-z - other characters removed)\n"
-	"-s <file> : output character wordlist (A-Za-z - other characters replaced by 0x0d)\n"
+	"-s <file> : output character wordlist (A-Za-z - other characters replaced by 0x0a)\n"
 	"            recommended option for processing with rules\n"
 	"-h        : show this help\n"
 	"-v        : show version\n"
@@ -160,7 +157,7 @@ fprintf(stdout, "%s %s (C) %s ZeroBeat\n"
 	"--version        : show version\n"
 	"\n"
 	"example:\n"
-	"$ hcxdumptool -i <interface> -o dump.pcapng --enable_status=31\n"
+	"$ hcxdumptool -i <interface> -w dump.pcapng\n"
 	"$ hcxpcapngtool -o hash.22000 -E elist dump.pcapng\n"
 	"$ hcxeiutool -i elist -d digitlist -x xdigitlist -c charlist -s sclist\n"
 	"$ cat elist digitlist xdigitlist charlist sclist > wordlisttmp\n"
