@@ -1,24 +1,24 @@
 #define _GNU_SOURCE
+#include <ctype.h>
 #include <getopt.h>
-#include <stdarg.h>
+#include <libgen.h>
+#include <limits.h>
+#include <stdbool.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdbool.h>
 #include <string.h>
-#include <ctype.h>
-#include <unistd.h>
-#include <time.h>
-#include <limits.h>
-#include <netinet/in.h>
-#include <sys/time.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#if defined (__APPLE__) || defined(__OpenBSD__)
-#include <libgen.h>
+#include <sys/time.h>
+#include <time.h>
+#include <unistd.h>
+
+#ifdef _WIN32
+#include <winsock2.h>
 #else
-#include <stdio_ext.h>
+#include <arpa/inet.h>
 #endif
+
 #include "include/hcxhash2cap.h"
 #include "include/hashcatops.h"
 #include "include/pcap.c"
@@ -31,7 +31,7 @@
 /*===========================================================================*/
 /* global var */
 
-struct timeval tv;
+static struct timeval tv;
 static uint64_t timestamp;
 
 static int mybeaconsequence;
@@ -49,7 +49,7 @@ static unsigned long long int johnwritten;
 static unsigned long long int johnskipped;
 
 /*===========================================================================*/
-static void globalinit()
+static void globalinit(void)
 {
 
 srand(time(NULL));
@@ -549,7 +549,7 @@ while((lineptr[p] != '*') && (lineptr[p] != 0) && (p /2 <= bufflen))
 	{
 	if(! isxdigit((unsigned char)lineptr[p +0])) return 0;
 	if(! isxdigit((unsigned char)lineptr[p +1])) return 0;
-	if((lineptr[p +1] == '*') && (lineptr[p +1] == 0)) return 0;
+	if((lineptr[p +1] == '*') || (lineptr[p +1] == 0)) return 0;
 	idx0 = ((uint8_t)lineptr[p +0] &0x1F) ^0x10;
 	idx1 = ((uint8_t)lineptr[p +1] &0x1F) ^0x10;
 	buff[p /2] = (uint8_t)(hashmap[idx0] <<4) | hashmap[idx1];
@@ -1296,7 +1296,7 @@ static uint8_t keyver;
 static uint64_t rc;
 
 
-static const char itoa64[64] = "./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
+static const char itoa64[65] = "./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
 
 static char singlecapname[PATH_MAX +2];
 static char linein[JOHN_LINE_LEN];
@@ -1562,6 +1562,10 @@ fprintf(stdout, "%s %s (C) %s ZeroBeat\n"
 	"--john=<file>        : input John the Ripper WPAPSK hash file\n"
 	"--help               : show this help\n"
 	"--version            : show version\n"
+	"\n"
+	"Important notice:\n"
+	"Conversion from a dump file to a hash file is not loss less.\n"
+	"Hash files that contain EAPOL M3 MESSAGEs can't be converted back to a cap file.\n"
 	"\n", eigenname, VERSION_TAG, VERSION_YEAR, eigenname);
 exit(EXIT_SUCCESS);
 }
