@@ -1,12 +1,13 @@
 #define OUILIST_MAX		50000
 #define OUI_LINE_LEN		50000
+#define OUIBUFFER_MAX		8192
 
 #define HCX_TYPE_PMKID		1
 #define HCX_TYPE_EAPOL		2
 
 #define ESSID_LEN_MIN 		0
 #define ESSID_LEN_MAX 		32
-#define EAPOL_AUTHLEN_MAX	256
+#define EAPOL_AUTHLEN_MAX	251
 
 #define PMKIDEAPOL_LINE_LEN	1024
 #define PMKIDEAPOL_BUFFER_LEN	1024
@@ -39,25 +40,29 @@
 #define HCX_FILTER_VENDOR_CLIENT	20
 #define HCX_FILTER_ESSID		21
 #define HCX_FILTER_ESSID_PART		22
-#define HCX_FILTER_RC			23
-#define HCX_FILTER_RC_NOT		24
-#define HCX_FILTER_M12			25
-#define HCX_FILTER_M1234		26
-#define HCX_FILTER_M1M2ROGUE		27
-#define HCX_PSK				28
-#define HCX_PMK				29
-#define HCX_VENDOR_OUT			30
-#define HCX_INFO_OUT			31
-#define HCX_INFO_VENDOR_OUT		32
-#define HCX_INFO_VENDOR_AP_OUT		33
-#define HCX_INFO_VENDOR_CLIENT_OUT	34
-#define HCX_HCCAPX_OUT			35
-#define HCX_HCCAP_OUT			36
-#define HCX_HCCAP_SINGLE_OUT		37
-#define HCX_JOHN_OUT			38
+#define HCX_FILTER_ESSID_PARTX		23
+#define HCX_FILTER_RC			24
+#define HCX_FILTER_RC_NOT		25
+#define HCX_FILTER_M12			26
+#define HCX_FILTER_M1234		27
+#define HCX_FILTER_M1M2ROGUE		28
+#define HCX_PSK				29
+#define HCX_PMK				30
+#define HCX_VENDOR_OUT			31
+#define HCX_INFO_OUT			32
+#define HCX_INFO_VENDOR_OUT		33
+#define HCX_INFO_VENDOR_AP_OUT		34
+#define HCX_INFO_VENDOR_CLIENT_OUT	35
+#define HCX_HCCAPX_IN			36
+#define HCX_HCCAPX_OUT			37
+#define HCX_HCCAP_IN			38
+#define HCX_HCCAP_OUT			39
+#define HCX_HCCAP_SINGLE_OUT		40
+#define HCX_JOHN_OUT			41
 #define HCX_PMKIDEAPOL_IN		'i'
 #define HCX_PMKIDEAPOL_OUT		'o'
 #define HCX_ESSID_OUT			'E'
+#define HCX_ESSID_RAW_OUT		'L'
 #define HCX_DOWNLOAD_OUI		'd'
 #define HCX_PBKDF2_IN			'p'
 #define HCX_HELP			'h'
