@@ -11,12 +11,15 @@
 #define HCX_CSV_OUT				11
 #define HCX_RAW_OUT				12
 #define HCX_RAW_IN				13
-#define HCX_LOG_OUT				14
-#define HCX_PMKID_OUT_DEPRECATED		15
-#define HCX_HCCAPX_OUT_DEPRECATED		16
-#define HCX_HCCAP_OUT_DEPRECATED		17
-#define HCX_PMKIDEAPOLJTR_OUT_DEPRECATED	18
-#define HCX_PREFIX_OUT				19
+#define HCX_LTS					14
+#define HCX_LOG_OUT				15
+#define HCX_PMKID_CLIENT_OUT			16
+#define HCX_PMKID_OUT_DEPRECATED		17
+#define HCX_HCCAPX_OUT_DEPRECATED		18
+#define HCX_HCCAP_OUT_DEPRECATED		19
+#define HCX_PMKIDEAPOLJTR_OUT_DEPRECATED	20
+#define HCX_PREFIX_OUT				21
+#define HCX_ADD_TIMESTAMP			22
 #define HCX_PMKIDEAPOL_OUT			'o'
 #define HCX_ESSID_OUT				'E'
 #define HCX_ESSIDPROBEREQUEST_OUT		'R'
@@ -36,7 +39,7 @@
 #define	OPTIONLEN_MAX			1024
 #define NMEA_MAX			256
 
-#define MAX_INTERFACE_ID		256
+#define MAX_INTERFACE_ID		255
 
 #define RAW_LEN_MAX			131072
 
@@ -44,7 +47,7 @@
 #define HANDSHAKELIST_MAX		100000
 #define PMKIDLIST_MAX			100000
 #define MESSAGELIST_MAX			64
-#define EAPOL_AUTHLEN_MAX		256
+#define EAPOL_AUTHLEN_MAX		251
 
 #define EAPMD5HASHLIST_MAX		1000
 #define EAPMD5MSGLIST_MAX		32
@@ -70,7 +73,7 @@
 #define TACACSPLIST_MAX			1000
 
 #define ESSIDSMAX			1
-#define EAPOLTIMEOUT			5000000
+#define EAPOLTIMEOUT			5000000000ULL
 #define NONCEERRORCORRECTION		0
 
 #define HCX_TYPE_PMKID			1
@@ -95,28 +98,33 @@ struct tags_s
 #define KV_WPAIE	2
  uint8_t		groupcipher;
  uint8_t		cipher;
-#define TCS_WEP40	0b00000001
-#define TCS_TKIP	0b00000010
-#define TCS_WRAP	0b00000100
-#define TCS_CCMP	0b00001000
-#define TCS_GCMP	0b00010000
-#define TCS_WEP104	0b00100000
-#define TCS_BIP		0b01000000
-#define TCS_NOT_ALLOWED	0b10000000
+#define TCS_WEP40	0x01
+#define TCS_TKIP	0x02
+#define TCS_WRAP	0x04
+#define TCS_CCMP	0x08
+#define TCS_GCMP	0x10
+#define TCS_WEP104	0x20
+#define TCS_BIP		0x40
+#define TCS_NOT_ALLOWED	0x80
  uint16_t		akm;
-#define	TAK_PMKSA	0b0000000000000001
-#define	TAK_PSK		0b0000000000000010
-#define TAK_FT		0b0000000000000100
-#define TAK_FT_PSK	0b0000000000001000
-#define	TAK_PMKSA256	0b0000000000010000
-#define	TAK_PSKSHA256	0b0000000000100000
-#define	TAK_TDLS	0b0000000001000000
-#define	TAK_SAE_SHA256	0b0000000010000000
-#define TAK_FT_SAE	0b0000000100000000
-#define TAK_AP_PKA	0b0000001000000000
-#define	TAK_SAE_SHA256B	0b0000010000000000
-#define	TAK_SAE_SHA384B	0b0000100000000000
-#define TAK_OWE		0b0001000000000000
+#define	TAK_PMKSA	0x0001
+#define	TAK_PSK		0x0002
+#define TAK_FT		0x0004
+#define TAK_FT_PSK	0x0008
+#define	TAK_PMKSA256	0x0010
+#define	TAK_PSKSHA256	0x0020
+#define	TAK_TDLS	0x0040
+#define	TAK_SAE_SHA256	0x0080
+#define TAK_FT_SAE	0x0100
+#define TAK_AP_PKA	0x0200
+#define	TAK_SAE_SHA256B	0x0400
+#define	TAK_SAE_SHA384B	0x0800
+#define TAK_OWE		0x1000
+ uint16_t		mdid;
+ uint8_t		r0khidlen;
+ uint8_t		r0khid[48];
+ uint8_t		r1khidlen;
+ uint8_t		r1khid[48];
  uint8_t		pmkid[16];
  uint8_t		wpsinfo;
  char			country[2];
@@ -145,8 +153,8 @@ struct maclist_s
  int			count;
  uint8_t		type;
 #define	REMOVED		0
-#define	CLIENT		1
-#define	AP		2
+#define	CLIENT		0x01
+#define	AP		0x02
  uint8_t		status;
 #define ST_PROBE_REQ	1
 #define ST_BEACON	2
@@ -244,10 +252,11 @@ struct messagelist_s
 #define	ST_M32E3	3
 #define	ST_M34E3	4
 #define	ST_M34E4	5
-#define	ST_APLESS	0b00010000
-#define	ST_LE		0b00100000
-#define	ST_BE		0b01000000
-#define	ST_NC		0b10000000
+#define	ST_APLESS	0x10
+#define	ST_LE		0x20
+#define	ST_BE		0x40
+#define	ST_ENDIANESS	0x60
+#define	ST_NC		0x80
  uint8_t		ap[6];
  uint8_t		client[6];
  uint8_t		message;
@@ -265,19 +274,20 @@ struct messagelist_s
 typedef struct messagelist_s messagelist_t;
 #define	MESSAGELIST_SIZE (sizeof(messagelist_t))
 
-static int sort_messagelist_by_epcount(const void *a, const void *b)
+static int sort_messagelist_by_timestamp(const void *a, const void *b)
 {
 const messagelist_t *ia = (const messagelist_t *)a;
 const messagelist_t *ib = (const messagelist_t *)b;
 
-if(ia->eapolmsgcount < ib->eapolmsgcount) return 1;
-else if(ia->eapolmsgcount > ib->eapolmsgcount) return -1;
+if(ia->timestamp < ib->timestamp) return 1;
+else if(ia->timestamp > ib->timestamp) return -1;
 return 0;
 }
 /*===========================================================================*/
 struct handshakelist_s
 {
  uint64_t		timestampgap;
+ uint64_t		timestamp;
  uint8_t		status;
  uint8_t		messageap;
  uint8_t		messageclient;
@@ -332,6 +342,9 @@ return 0;
 struct pmkidlist_s
 {
  uint64_t		timestamp;
+ uint8_t		status;
+#define PMKID_AP	0x01
+#define PMKID_CLIENT	0x10
  uint8_t		ap[6];
  uint8_t		client[6];
  uint8_t		anonce[32];
