@@ -18,18 +18,7 @@ uint8_t p;
 for(p = 0; p < len; p++)
 	{
 	if(buffer[p] == 0) return true;
-	if((buffer[p] < 0x20) || (buffer[p] > 0x7e) || (buffer[p] == ':')) return false;
-	}
-return true;
-}
-/*===========================================================================*/
-bool isasciistring2(int len, uint8_t *buffer)
-{
-uint8_t p;
-for(p = 0; p < len; p++)
-	{
-	if(buffer[p] == 0) return true;
-	if((buffer[p] < 0x20) || (buffer[p] > 0x7e)) return false;
+	if((buffer[p] < 0x20) || (buffer[p] == 0x7f)) return false;
 	}
 return true;
 }
@@ -100,7 +89,7 @@ size_t i;
 uint8_t j;
 char** to;
 
-to = malloc(size * sizeof(char *));
+to = (char**)malloc(size * sizeof(char *));
 if(to == NULL)
 	{
 	fprintf(stderr, "failed to allocate memory\n");
@@ -110,7 +99,7 @@ if(to == NULL)
 for (i = 0; i < size; i++)
     {
     len = strlen(from[i]);
-    to[i] = malloc(len * sizeof(char) + 1);
+    to[i] = (char*)malloc(len * sizeof(char) + 1);
 	if(to[i] == NULL)
 		{
 		fprintf(stderr, "failed to allocate memory\n");
